<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


// On page reload, QueryResult object will be defined
try {
    if (! $QueryResult) {
        $SimpleQuery = new Query('dummy');
        $QueryResult = new QueryResult(false,$SimpleQuery,0);
    }
}
catch (Exception $e) {
    $App->log('[searchSimple] '.$e->getMessage());
    $App->setMsg($e->getMessage());
}

if($exitview = $App->getParam('exitview')) {
    $App->setSession('exitview',$exitview);
}

$show_greeting = true;
// enable template code for asyncronous dummy request
$App->assign('CACHE_WARMING_REQUEST','true');
$App->view = 'showList';


?>
